@@ -74,6 +74,8 @@ class JNIBackend(JavaBackend):
 class JavaObject(object):
 
 	def __init__(self, backend):
+		if not isinstance(backend, JavaBackend):
+			raise TypeError()
 		self.backend = backend
 
 class JavaError(JavaObject, Exception):
@@ -173,6 +175,9 @@ class Evaluator(JavaObject):
 				results_df.drop(str(dropColumn), axis = 1, inplace = True)
 		return results_df
 
+	def predict(self, X):
+		return self.evaluateAll(X)
+
 	def suppressResultFields(self, resultFields):
 		if resultFields:
 			self.dropColumns = [resultField.getName() for resultField in resultFields]
@@ -224,17 +229,33 @@ class LoadingModelEvaluatorBuilder(BaseModelEvaluatorBuilder):
 		self.javaModelEvaluatorBuilder.load(file)
 		return self
 
-def make_evaluator(backend, path, lax = False, locatable = False, reporting = False):
+def make_backend(alias):
+	if not isinstance(alias, str):
+		raise TypeError()
+	if alias.lower() == "jpype":
+		from jpmml_evaluator.jpype import JPypeBackend
+		return JPypeBackend()
+	elif alias.lower() == "pyjnius":
+		from jpmml_evaluator.pyjnius import PyJNIusBackend
+		return PyJNIusBackend()
+	elif alias.lower() == "py4j":
+		from jpmml_evaluator.py4j import Py4JBackend
+		return Py4JBackend()
+	else:
+		aliases = ["jpype", "pyjnius", "py4j"]
+		raise ValueError("Java backend alias {0} not in {1}".format(alias, aliases))
+
+def make_evaluator(path, backend = "jpype", lax = False, locatable = False, reporting = False):
 	""" Builds an Evaluator based on a PMML file.
 
 	Parameters:
 	----------
-	backend: JavaBackend
-		The Java backend.
-
 	path: string
 		The path to the PMML file in local filesystem.
 
+	backend: JavaBackend or string
+		The Java backend or its alias
+
 	lax: boolean
 		If True, skip model schema sanity checks.
 
@@ -245,6 +266,14 @@ def make_evaluator(backend, path, lax = False, locatable = False, reporting = Fa
 	reporting: boolean
 		If True, activate the reporting Value API.
 	"""
+
+	if isinstance(backend, JavaBackend):
+		pass
+	elif isinstance(backend, str):
+		backend = make_backend(backend)
+	else:
+		raise TypeError()
+
 	evaluatorBuilder = LoadingModelEvaluatorBuilder(backend, lax) \
 		.setLocatable(locatable) \
 		.loadFile(path)
